@@ -61,6 +61,9 @@ def _ensure_neutron_network(sdk):
 
     return network
 
+def _get_nameservers_for_version(servers, ipversion):
+    """Get list of nameservers for an IP version"""
+    return [s for s in servers if netaddr.IPAddress(s).version == ipversion]
 
 def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
                            allocation_pools, name, segment_id, dns_nameservers):
@@ -77,7 +80,8 @@ def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
                 allocation_pools=allocation_pools,
                 network_id=network_id,
                 segment_id=segment_id,
-                dns_nameservers=dns_nameservers)
+                dns_nameservers=_get_nameservers_for_version(dns_nameservers,
+                                                             6))
         else:
             subnet = sdk.network.create_subnet(
                 name=name,
@@ -89,7 +93,8 @@ def _neutron_subnet_create(sdk, network_id, cidr, gateway, host_routes,
                 allocation_pools=allocation_pools,
                 network_id=network_id,
                 segment_id=segment_id,
-                dns_nameservers=dns_nameservers)
+                dns_nameservers=_get_nameservers_for_version(dns_nameservers,
+                                                             4))
             print('INFO: Subnet created %s' % subnet)
     except Exception:
         print('ERROR: Create subnet %s failed.' % name)
@@ -107,7 +112,8 @@ def _neutron_subnet_update(sdk, subnet_id, cidr, gateway, host_routes,
                 name=name,
                 gateway_ip=gateway,
                 allocation_pools=allocation_pools,
-                dns_nameservers=dns_nameservers)
+                dns_nameservers=_get_nameservers_for_version(dns_nameservers,
+                                                             6))
         else:
             subnet = sdk.network.update_subnet(
                 subnet_id,
@@ -115,7 +121,8 @@ def _neutron_subnet_update(sdk, subnet_id, cidr, gateway, host_routes,
                 gateway_ip=gateway,
                 host_routes=host_routes,
                 allocation_pools=allocation_pools,
-                dns_nameservers=dns_nameservers)
+                dns_nameservers=_get_nameservers_for_version(dns_nameservers,
+                                                             4))
         print('INFO: Subnet updated %s' % subnet)
     except Exception:
         print('ERROR: Update of subnet %s failed.' % name)
@@ -205,6 +212,7 @@ def _local_neutron_segments_and_subnets(sdk, ctlplane_id, net_cidrs):
     segment = _get_segment(sdk, CONF['physical_network'], ctlplane_id)
     host_routes = [{'destination': '169.254.169.254/32',
                     'nexthop': CONF['local_ip']}]
+    host_routes += s['HostRoutes']
     if subnet:
         if CONF['enable_routed_networks'] and subnet.segment_id == None:
             # The subnet exists and does not have a segment association. Since
@@ -245,6 +253,7 @@ def _remote_neutron_segments_and_subnets(sdk, ctlplane_id, net_cidrs):
         metadata_nexthop = s['NetworkGateway']
         host_routes = [{'destination': '169.254.169.254/32',
                         'nexthop': metadata_nexthop}]
+        host_routes += s['HostRoutes']
         subnet = _get_subnet(sdk, s['NetworkCidr'], ctlplane_id)
         segment = _get_segment(sdk, phynet, ctlplane_id)
         if subnet:
