@@ -39,12 +39,11 @@ def parse_opts(argv):
                         default=('%s/network_data.yaml') % DEFAULT_THT_DIR)
     parser.add_argument('--role-name', metavar='ROLE-NAME',
                         help="Name of the role the NIC config is used for.",
-                        default='Controller')
+                        required=True)
     parser.add_argument('-t', '--template', metavar='TEMPLATE_FILE',
                         help=("Existing NIC config template to merge "
                               "parameter too."),
-                        required=True,
-                        )
+                        required=True)
     parser.add_argument('--tht-dir', metavar='THT_DIR',
                         help=("Path to tripleo-heat-templates (THT) "
                               "directory"),
@@ -201,7 +200,7 @@ def process_templates_and_get_reference_parameters():
            '--network-data ' + OPTS.network_data,
            '--output-dir ' + temp_dir]
     child = subprocess.Popen(' '.join(cmd), shell=True, stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE)
+                             stderr=subprocess.PIPE, universal_newlines=True)
     out, err = child.communicate()
     if not child.returncode == 0:
         raise RuntimeError('Error processing templates: %s' % err)
@@ -210,9 +209,15 @@ def process_templates_and_get_reference_parameters():
     # be used when loading the reference file.
     with open(OPTS.roles_data) as roles_data_file:
         roles_data = yaml.safe_load(roles_data_file)
-    nic_config_name = next((x.get('deprecated_nic_config_name',
-                                  OPTS.role_name.lower() + '.yaml') for x in
-                            roles_data if x['name'] == OPTS.role_name))
+    try:
+        nic_config_name = next((x.get('deprecated_nic_config_name',
+                                      OPTS.role_name.lower() + '.yaml')
+                                for x in roles_data
+                                if x['name'] == OPTS.role_name))
+    except StopIteration:
+        raise RuntimeError('The role: {role_name} is not defined in roles '
+                           'data file: {roles_data_file}'.format(
+            role_name=OPTS.role_name, roles_data_file=OPTS.roles_data))
 
     refernce_file = '/'.join([temp_dir, 'network/config', NIC_CONFIG_REFERENCE,
                               nic_config_name])
