@@ -445,7 +445,7 @@ def validate_controller_no_ceph_role(filename, tpl):
                 return 1
     return 0
 
-def validate_with_compute_role_services(role_filename, role_tpl, exclude_service):
+def validate_with_compute_role_services(role_filename, role_tpl, exclude_service=()):
     cmpt_filename = os.path.join(os.path.dirname(role_filename),
                                  './Compute.yaml')
     cmpt_tpl = yaml.load(open(cmpt_filename).read())
@@ -459,8 +459,27 @@ def validate_with_compute_role_services(role_filename, role_tpl, exclude_service
               'ServicesDefault in roles/Compute.yaml'.format(role_filename,
               ', '.join(missing_services)))
         return 1
-    return 0
 
+    cmpt_us = cmpt_tpl[0].get('update_serial', None)
+    tpl_us = role_tpl[0].get('update_serial', None)
+
+    if 'OS::TripleO::Services::CephOSD' in role_services:
+        if tpl_us not in (None, 1):
+            print('ERROR: update_serial in {0} ({1}) '
+                  'is should be 1 as it includes CephOSD'.format(
+                      role_filename,
+                      tpl_us,
+                      cmpt_us))
+            return 1
+    elif cmpt_us is not None and tpl_us != cmpt_us:
+        print('ERROR: update_serial in {0} ({1}) '
+              'does not match roles/Compute.yaml {2}'.format(
+                  role_filename,
+                  tpl_us,
+                  cmpt_us))
+        return 1
+
+    return 0
 
 def validate_multiarch_compute_roles(role_filename, role_tpl):
     errors = 0
@@ -1108,6 +1127,10 @@ def validate(filename, param_map):
         if filename == './roles/Compute.yaml':
             retval |= validate_multiarch_compute_roles(filename, tpl)
 
+        if filename in ('./roles/ComputeLocalEphemeral.yaml',
+                        './roles/ComputeRBDEphemeral.yaml'):
+            retval |= validate_with_compute_role_services(filename, tpl)
+
         # NOTE(hjensas): The routed network data example is very different ...
         # We need to develop a more advanced validator, probably using a schema
         # definition instead.
